# Changelog

All notable changes to this project will be documented in this file.

## [0.1.9] - 2025-02-13

### Commits
- Update CHANGELOG.md template for release process
- Refactor changelog generation and update release documentation
- Refactor state methods and improve web browser interaction logging

### Added


### Fixed


### Changed




## [v0.1.8] - 2025-02-13

### Commits
- Release 0.1.8
- Release 0.1.7
- Revamp README with comprehensive project overview and usage guide
- Bump version to 0.1.6
- Refactor web processing and navigation handling
- Enhance utility functions and doer interfaces
- Refactor Wolfram Alpha test case and enhance SuperDoer realm configuration
- Update system prompts and documentation for browser and doer tools
- Refactor provisions and update project documentation
- Uncomment and activate MCPRun test case in test_new.py
- Merge branch 'feature/mcp-run-task' into feature/new
- Update dependencies and refactor package structure
- add envpaths .. not using it yet but its here
- mcprunner polishing
- latest
- I dont like it
- reimplement everything
- Refactor NewMCPTask to NewMCPRunTask as a Provision tool
- Merge branch 'feature/new' into feature/mcp-run-task
- Add security warning and update browser notebook interactions
- structure and tests
- Update local runtime license header with donew modifications
- Add browser notebook and refactor DO system initialization
- Refactor WebProcessor and WebPage to support more flexible browser configuration
- Rename Tool classes to Assistants for better semantic clarity
- init mcprun
- Add name and purpose to SuperDoer and NewTool
- Merge branch 'feature/new' of https://github.com/DONEWio/See into feature/new
- Enhance browser configuration and element detection capabilities
- fix envision part to make it work again with non pydantic schemas
- Add enhanced error handling and verification for FinalAnswerTool
- Enhance tracing and browsing capabilities in SuperDoer and BrowseTool
- Add documentation and browse agent support for DO system
- add tests for non pydantic validations and envisions
- result verification
- improve pydantic_model_to_simple_schema
- make pydantic_model_to_simple_schema great
- add pydantic schema to simplified llm schema
- Enhance tracing capabilities and update dependencies
- Update VSCode settings to disable debugpy's Just My Code feature for improved debugging experience
- added test for structured output. turns out it is already supported out of box
- Update README.md and KnowledgeGraph configuration
- Remove obsolete script entry from pyproject.toml to streamline installation process
- Update dependencies and refine installation instructions
- Update Knowledge Graph functionality and enhance README instructions
- Refactor sync/async methods and enhance utility functions
- Refactor DO class to enhance async method naming and update tests
- sync/async capabilities part 1
- Add async query method to BaseTarget and corresponding tests
- Refactor KnowledgeGraph and enhance analysis capabilities
- Update README.md to clarify optional spaCy model installations
- Enhance KnowledgeGraph initialization and testing for multi-language support
- Update dependencies and enhance Knowledge Graph functionality
- Enhance Knowledge Graph functionality and documentation
- Update project for Knowledge Graph functionality
- Update VSCode settings to specify default Python interpreter path

### Added


### Fixed


### Changed

## [v0.1.5] - 2025-02-13

### Commits
- Add MANIFEST.in, update pyproject.toml, and modify README for development setup
- Release v0.1.5: Fix package distribution issues and update version
- Implement element detection and highlighting features
- Release v0.1.4
- Refactor project structure and enhance testing configuration
- Enhance type safety and structure in processors module
- Update CHANGELOG for version 0.1.3: remove version fetching from pyproject.toml
- Update version to 0.1.3 and add release process documentation
- grab version from pyproject.
- chore: bump version to 0.1.2
- fix id type from str to int.
- fix element handling issues when website navigates. fix chromium bug for 404 status codes.
- remove wip files
- add badges
- bump version
- fix: rename DoNew to donew for package consistency

### Added


### Fixed
- fix: rename DoNew to donew for package consistency

### Changed

## [v0.1.0] - 2025-02-13

### Commits
- prep for release
- make headless config as global setting
- fix svg
- add httpbin as local test

### Added


### Fixed


### Changed
